==> grizzly-http-servlet-2.1.2-sources.jar: org/glassfish/grizzly/servlet/FilterConfigImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 *
 * This file incorporates work covered by the following copyright and
 * permission notice:
 *
 * Copyright 2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glassfish.grizzly.servlet;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Map;

import javax.servlet.Filter;
import javax.servlet.FilterConfig;
import javax.servlet.ServletContext;
import org.glassfish.grizzly.http.server.util.Enumerator;


/**
 * {@link FilterConfig} implementation.
 * 
 * @author Jeanfrancois Arcand
 */
@SuppressWarnings("unchecked")
public final class FilterConfigImpl implements FilterConfig {

    
    /**
     * The Context with which we are associated.
     */
    private ServletContextImpl servletContext = null;
    
    
    /**
     * The application Filter we are configured for.
     */
    private Filter filter = null;
    
    
    /**
     * Filter's initParameters.
     */
    private Map initParameters = null;
    
    
    /**
     * Filter name
     */
    private String filterName;

    
    // ------------------------------------------------------------------ //
    

    
    public FilterConfigImpl(ServletContextImpl servletContext) {
        this.servletContext = servletContext;
    }

    
    /**
     * {@inheritDoc}
     */    
    @Override
    public String getInitParameter(String name) {
        if (initParameters == null) {
            return null;
        }
        return ((String) initParameters.get(name));
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    public String getFilterName() {
        return filterName;
    }
    
    
    /**
     * {@inheritDoc}
     */
    @Override
    public Enumeration getInitParameterNames() {
        Map map = initParameters;
        if (map == null) {
            return (new Enumerator(new ArrayList()));
        } else {
            return (new Enumerator(map.keySet()));
        }
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    public ServletContext getServletContext() {
        return servletContext;
    }

    
    /**
     * Return the application Filter we are configured for.
     */
    public Filter getFilter(){
       return filter;
    }

    
    /**
     * Release the Filter instance associated with this FilterConfig,
     * if there is one.
     */
    protected void recycle() {
        if (this.filter != null) {
            filter.destroy();
        }
        this.filter = null;
    }


    /**
     * Set the {@link Filter} associated with this object.
     * @param filter
     */
    protected void setFilter(Filter filter) {
        this.filter = filter;
    }

    
    /**
     * Set the {@link Filter}'s name associated with this object.
     * @param filterName the name of this {@link Filter}.
     */    
    protected void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    
    /**
     * Set the init parameters associated with this associated {@link Filter}.
     * @param initParameters the configuration parameters for this {@link Filter}
     */    
    protected void setInitParameters(Map initParameters) {
        this.initParameters = initParameters;
    }
}

==> grizzly-http-servlet-2.2.16-sources.jar: org/glassfish/grizzly/servlet/FilterConfigImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 *
 * This file incorporates work covered by the following copyright and
 * permission notice:
 *
 * Copyright 2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glassfish.grizzly.servlet;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Map;

import javax.servlet.Filter;
import javax.servlet.FilterConfig;
import javax.servlet.ServletContext;
import org.glassfish.grizzly.http.server.util.Enumerator;


/**
 * {@link FilterConfig} implementation.
 * 
 * @author Jeanfrancois Arcand
 */
@SuppressWarnings("unchecked")
public class FilterConfigImpl implements FilterConfig {

    
    /**
     * The Context with which we are associated.
     */
    private WebappContext servletContext = null;
    
    
    /**
     * The application Filter we are configured for.
     */
    private Filter filter = null;
    
    
    /**
     * Filter's initParameters.
     */
    private Map initParameters = null;
    
    
    /**
     * Filter name
     */
    private String filterName;

    
    // ------------------------------------------------------------------ //
    

    
    public FilterConfigImpl(WebappContext servletContext) {
        this.servletContext = servletContext;
    }

    
    /**
     * {@inheritDoc}
     */    
    @Override
    public String getInitParameter(String name) {
        if (initParameters == null) {
            return null;
        }
        return ((String) initParameters.get(name));
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    public String getFilterName() {
        return filterName;
    }
    
    
    /**
     * {@inheritDoc}
     */
    @Override
    public Enumeration getInitParameterNames() {
        Map map = initParameters;
        if (map == null) {
            return (new Enumerator(new ArrayList()));
        } else {
            return (new Enumerator(map.keySet()));
        }
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    public ServletContext getServletContext() {
        return servletContext;
    }

    
    /**
     * Return the application Filter we are configured for.
     */
    public Filter getFilter(){
       return filter;
    }

    
    /**
     * Release the Filter instance associated with this FilterConfig,
     * if there is one.
     */
    protected void recycle() {
        if (this.filter != null) {
            filter.destroy();
        }
        this.filter = null;
    }


    /**
     * Set the {@link Filter} associated with this object.
     * @param filter
     */
    protected void setFilter(Filter filter) {
        this.filter = filter;
    }

    
    /**
     * Set the {@link Filter}'s name associated with this object.
     * @param filterName the name of this {@link Filter}.
     */    
    protected void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    
    /**
     * Set the init parameters associated with this associated {@link Filter}.
     * @param initParameters the configuration parameters for this {@link Filter}
     */    
    protected void setInitParameters(Map initParameters) {
        if (initParameters != null && !initParameters.isEmpty()) {
            this.initParameters = initParameters;
        }
    }
}
